@@ -36,5 +36,5 @@ const project = new cdk.JsiiProject({
   // packageName: undefined,  /* The "name" in package.json. */
 });
 
-project.addTask('coverage', {});
+// project.addTask('coverage', {});
 project.synth();
\ No newline at end of file
