@@ -2,7 +2,8 @@
 # lazy-constructs
 
 [![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
-[![codecov](https://codecov.io/gh/lazinessdevs/lazy-constructs/branch/main/graph/badge.svg?token=U1R3MKJWJO)](https://codecov.io/gh/lazinessdevs/lazy-constructs)
+
+[![codecov](https://codecov.io/gh/lazinessdevs/lazy-constructs/branch/main/graph/badge.svg?token=ENFG0OQBOZ)](https://codecov.io/gh/lazinessdevs/lazy-constructs)
 
 [![NPM version](https://img.shields.io/npm/v/lazy-constructs?label=pypi%20package&color=brightgreen)](https://badge.fury.io/js/lazy-constructs)
 [![PyPI version](https://img.shields.io/pypi/v/lazy-constructs?label=pypi%20package&color=brightgreen)](https://badge.fury.io/py/lazy-constructs)
